#ifndef NT2_INCLUDE_FUNCTIONS_ACSC_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACSC_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/acsc.hpp>

#endif
